@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_update_conf.pl 5196 2005-12-02 13:34:58Z yeupou $
+# $Id: sv_update_conf.pl 5279 2006-02-01 17:40:13Z yeupou $
 #
 #  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Sylvain Beucler <beuc--beuc.net>
@@ -235,7 +235,7 @@ if ($recreate) {
       AskSetting("sys_default_locale", "Default locale", "It must be a valid locale name.", "fr_FR", $sys_default_locale);
       AskSetting("sys_datefmt", "Date format", "Date formatting. Savane normally does a pretty good job at providing a correctly localized date. Unless you really know what you are doing, leave this commented out.", "%Y-%m-%d %H:%M", $sys_datefmt);
 
-      AskSetting("sys_themedefault", "Default theme", "--", "emerald", $sys_themedefault);
+      AskSetting("sys_themedefault", "Default theme", "--", "emeraud", $sys_themedefault);
       AskSetting("sys_logo_name", "Logo name", "The engine will search for a file like savannah/frontend/php/images/\$theme.theme/\$sys_logo_name. If you do not want any logo, comment out", "floating.png", $sys_logo_name);
 
 
@@ -300,7 +300,7 @@ if ($recreate) {
 #
 # Savane Site Configuration:
 #
-# \$Id: sv_update_conf.pl 5196 2005-12-02 13:34:58Z yeupou $
+# \$Id: sv_update_conf.pl 5279 2006-02-01 17:40:13Z yeupou $
 #
 # This file has been generated by sv_update_conf
 # If you modify it, run sv_update_conf --update
@@ -420,7 +420,7 @@ use warnings;
       # Default theme, logo filename
       # The engine will search for a file like
       #    frontend/php/images/\$theme.theme/$sys_logo_name
-      # Ex: "emerald", "floating.png"
+      # Ex: "emeraud", "floating.png"
         # REQUIRED
         $sys_themedefault
         # OPTIONAL (comment out if not appliable)
