@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: lostpw-confirm.php 4763 2005-09-14 16:18:31Z toddy $
+# $Id: lostpw-confirm.php 5267 2005-12-22 00:34:38Z beuc $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -105,15 +105,16 @@ else
 db_query("UPDATE user SET confirm_hash='$confirm_hash' WHERE user_id=$row_user[user_id]");
 
 $message = sprintf(_("Someone (presumably you) on the %s site requested a password change through email verification."),$GLOBALS['sys_default_domain']);
+$message .= ' ';
 $message .= _("If this was not you, this could pose a security risk for the system.")."\n\n";
 $message .= sprintf(_("The request came from %s"),gethostbyaddr($GLOBALS['REMOTE_ADDR']))."\n";
-$message .= '(IP: '.$GLOBALS['REMOTE_ADDR'].' port: '.$GLOBALS['REMOTE_PORT'].')\n';
+$message .= '(IP: '.$GLOBALS['REMOTE_ADDR'].' port: '.$GLOBALS['REMOTE_PORT'].")\n";
 $message .= _("with").' '.$GLOBALS['HTTP_USER_AGENT']."\n\n";
-$message .= _("If you requested this verification, visit the same URL\nto change your password:")."\n\n";
+$message .= _("If you requested this verification, visit this URL\nto change your password:")."\n\n";
 $message .= $GLOBALS['sys_https_url'].$GLOBALS['sys_home']."account/lostlogin.php?confirm_hash=".$confirm_hash."\n\n";
 # There should be a discard procedure
 $message .= _("If you did not request this verification, please visit this URL to cancel it.")."\n\n";
-$message .= _("In any case make sure that you do not disclose this url to\n sombody else, e.g. do not mail this to a public mailinglist!\n\n");
+$message .= _("In any case make sure that you do not disclose this url to\n somebody else, e.g. do not mail this to a public mailinglist!\n\n");
 $message .= sprintf(_("-- the %s team."),$GLOBALS['sys_name'])."\n";
 
 # We should not add i18n to admin messages
