@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.87 2005/06/30 17:19:33 toddy Exp $
+# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -36,7 +36,8 @@ if (!$project->Uses("cvs") && !$project->UsesForHomepage("cvs"))
   exit_error(_("This project has turned off this tool"));
 }
 
-site_project_header(array('group'=>$group_id,'toptab'=>'cvs'));
+site_project_header(array('group'=>$group_id,'context'=>'cvs'));
+
 
 
 # ####################### CVS Browsing
