@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: add.php,v 1.13 2005/06/30 17:19:34 toddy Exp $
+# $Id: add.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 2002-2003 (c) Mathieu Roy <yeupou--at--gnu.org>
 #
@@ -35,7 +35,8 @@ if ($group_id) {
 
     site_project_header(array('title'=>_("Add"),
 			      'group'=>$group_id,
-			      'toptab'=>'download'));
+			      'context'=>'download'));
+
 
     # NOTE: because it was not really needed for the backend and frontend,
     # the download host configuration  per group type has been removed.
