@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: form.php,v 1.3 2005/06/30 17:19:35 toddy Exp $
+# $Id: form.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -105,7 +105,7 @@ function form_check ($form_id)
 # Remove form_id from database: the item was posted
 function form_clean ($form_id)
 {
-  $success = db_affected_rows(db_query("DELETE FROM form WHERE user_id='".user_getid()."' AND form_id='".addslashes($form_id)."'"));
+  $success = db_affected_rows(db_query("DELETE FROM form WHERE user_id='".user_getid()."' AND form_id='".safeinput($form_id)."'"));
   if (!$success)
     { fb(_("Error during unique form_id removal"), 1); }
   
