@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.17 2005/09/21 15:53:23 yeupou Exp $
+# $Id: general.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
@@ -45,7 +45,6 @@ Output:
 
 */
 
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':my_hide_url ($svc, $db_item_id, $item_id, $count, $hide) ';
   global $PHP_SELF;
 
   $pref_name = 'my_hide_'.$svc.$db_item_id;
@@ -106,7 +105,6 @@ Output:
 
 function my_format_as_flag($assigned_to, $submitted_by)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':my_format_as_flag($assigned_to, $submitted_by) ';
   $AS_flag = '';
   if ($assigned_to == user_getid())
     {
@@ -123,7 +121,6 @@ function my_format_as_flag($assigned_to, $submitted_by)
 
 function my_item_count($total, $new)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':my_item_count($total, $new) ';
   $ret = '(';
   $ret .= sprintf(ngettext("%s item", "%s items", $total), $total);
   if ($new)
@@ -151,7 +148,7 @@ function my_item_list ($role="assignee", $threshold="5", $status="open") {
   $item_resolution_id = array();
   $item_summary = array();
 
-  $trackers = array("support", "bugs", "task", "patch");
+  $trackers = array("support", "bugs", "task", "cookbook", "patch");
   $results = 0;
 
 
@@ -179,6 +176,7 @@ function my_item_list ($role="assignee", $threshold="5", $status="open") {
 	  $sql .= 'AND '.$tracker.'.assigned_to<>'.$uid.' AND '.$tracker.'.submitted_by='.$uid.' ';
 	}
       $sql .= 'ORDER BY '.$tracker.'.date DESC ';
+
       $result=db_query($sql);
       $rows=db_numrows($result);
       if ($result && $rows > 0)
@@ -244,10 +242,10 @@ function my_item_list ($role="assignee", $threshold="5", $status="open") {
 	    '&nbsp;<font class="smaller">['.$dstatus.']</font></div>';
 
 	}
-      arsort($thisgroupcontent);
+      krsort($thisgroupcontent);
       $count = count($thisgroupcontent);
 
-      list($hide_now,$count_diff,$hide_url) = my_hide_url($role,$thisgroupid,$GLOBALS['hide_group_id'],$count,$GLOBALS['hide_'.$role], '&nbsp;<b>'.$thisgroupfullname.'</b>');
+      list($hide_now,$count_diff,$hide_url) = my_hide_url($role,$thisgroupid,sane_get("hide_group_id"),$count,sane_get("hide_$role"), '&nbsp;<b>'.$thisgroupfullname.'</b>');
       
       print '<div class="'.utils_altrow(1).'"> '.$hide_url.' <font class="smaller">'.my_item_count($count,max(0, $count_diff)).'</font></div>';
 
@@ -278,7 +276,7 @@ function my_incoming_unassigned_item_list ($groups) {
   $item_resolution_id = array();
   $item_summary = array();
 
-  $trackers = array("support", "bugs", "task", "patch");
+  $trackers = array("support", "bugs", "task", "cookbook", "patch");
   $results = 0;
 
 
@@ -388,10 +386,10 @@ function my_incoming_unassigned_item_list ($groups) {
 	    '&nbsp;<font class="smaller">['.$dstatus.']</font></div>';
 
 	}
-      arsort($thisgroupcontent);
+      krsort($thisgroupcontent);
       $count = count($thisgroupcontent);
 
-      list($hide_now,$count_diff,$hide_url) = my_hide_url("unassigned",$thisgroupid,$GLOBALS['hide_group_id'],$count,$GLOBALS['hide_unassigned'], '&nbsp;<b>'.$thisgroupfullname.'</b>');
+      list($hide_now,$count_diff,$hide_url) = my_hide_url("unassigned",$thisgroupid,sane_get("hide_group_id"),$count,sane_get("hide_unassigned"), '&nbsp;<b>'.$thisgroupfullname.'</b>');
 
       print '<div class="'.utils_altrow(1).'">'.$hide_url.' <font class="smaller">'.my_item_count($count,max(0, $count_diff)).'</font></div>';
 
@@ -421,7 +419,7 @@ function my_incoming_assigned_item_list ($groups) {
   $item_resolution_id = array();
   $item_summary = array();
 
-  $trackers = array("support", "bugs", "task", "patch");
+  $trackers = array("support", "bugs", "task", "patch", "cookbook");
   $results = 0;
 
 
@@ -580,10 +578,10 @@ function my_incoming_assigned_item_list ($groups) {
 	    '&nbsp;<font class="smaller">['.$dstatus.']</font></div>';
 
 	}
-      arsort($thisgroupcontent);
+      krsort($thisgroupcontent);
       $count = count($thisgroupcontent);
 
-      list($hide_now,$count_diff,$hide_url) = my_hide_url("newlyassigned",$thisgroupid,$GLOBALS['hide_group_id'],$count,$GLOBALS['hide_newlyassigned'], '&nbsp;<b>'.$thisgroupfullname.'</b>');
+      list($hide_now,$count_diff,$hide_url) = my_hide_url("newlyassigned",$thisgroupid,sane_get("hide_group_id"),$count,sane_get("hide_newlyassigned"), '&nbsp;<b>'.$thisgroupfullname.'</b>');
 
       print '<div class="'.utils_altrow(1).'">'.$hide_url.' <font class="smaller">'.my_item_count($count,max(0, $count_diff)).'</font></div>';
 
