@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.5 2005/08/31 21:05:09 yeupou Exp $
+# $Id: general.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -31,7 +31,6 @@
 
 function people_get_category_name($category_id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_get_category_name($category_id) ';
   $sql="SELECT name FROM people_job_category WHERE category_id='$category_id'";
   $result=db_query($sql);
   if (!$result || db_numrows($result) < 1)
@@ -46,7 +45,6 @@ function people_get_category_name($category_id)
 
 function people_show_category_table()
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_show_category_table() ';
 
   #show a list of categories in a table
   #provide links to drill into a detail page that shows these categories
@@ -80,7 +78,6 @@ function people_show_category_table()
 
 function people_show_category_list()
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_show_category_list() ';
 
   #show a list of categories
   #provide links to drill into a detail page that shows these categories
@@ -117,7 +114,6 @@ function people_show_category_list()
 
 function people_show_category_jobs($category_id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_show_category_jobs($category_id) ';
   #show open jobs for this category
   $sql="SELECT people_job.group_id,people_job.job_id,groups.unix_group_name,groups.group_name,groups.type,people_job.title,people_job.date,people_job_category.name AS category_name ".
      "FROM people_job,people_job_category,groups ".
@@ -135,7 +131,6 @@ function people_show_category_jobs($category_id)
 
 function people_job_status_box($name='status_id',$checked='xyxy')
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_job_status_box ';
   $sql="SELECT * FROM people_job_status";
   $result=db_query($sql);
   return html_build_select_box ($result,$name,$checked);
@@ -143,7 +138,6 @@ function people_job_status_box($name='status_id',$checked='xyxy')
 
 function people_job_category_box($name='category_id',$checked='xyxy')
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_job_category_box ';
   $sql="SELECT * FROM people_job_category";
   $result=db_query($sql);
   return html_build_select_box ($result,$name,$checked);
@@ -151,7 +145,6 @@ function people_job_category_box($name='category_id',$checked='xyxy')
 
 function people_add_to_job_inventory($job_id,$skill_id,$skill_level_id,$skill_year_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_add_to_job_inventory($job_id,$skill_id,$skill_level_id,$skill_year_id) ';
   global $feedback;
   if (user_isloggedin())
     {
@@ -188,7 +181,6 @@ function people_add_to_job_inventory($job_id,$skill_id,$skill_level_id,$skill_ye
 
 function people_show_job_inventory($job_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_show_job_inventory($job_id) ';
   $sql="SELECT people_skill.name AS skill_name, people_skill_level.name AS level_name, people_skill_year.name AS year_name ".
      "FROM people_skill_year,people_skill_level,people_skill,people_job_inventory ".
      "WHERE people_skill_year.skill_year_id=people_job_inventory.skill_year_id ".
@@ -232,7 +224,6 @@ function people_show_job_inventory($job_id)
 
 function people_verify_job_group($job_id,$group_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_verify_job_group($job_id,$group_id) ';
   $sql="SELECT * FROM people_job WHERE job_id='$job_id' AND group_id='$group_id'";
   $result=db_query($sql);
   if (!$result || db_numrows($result) < 1)
@@ -247,7 +238,6 @@ function people_verify_job_group($job_id,$group_id)
 
 function people_edit_job_inventory($job_id,$group_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_edit_job_inventory($job_id,$group_id) ';
 
   global $PHP_SELF;
   $sql="SELECT *,people_skill.name AS skill_name FROM people_job_inventory,people_skill WHERE job_id='$job_id' AND people_skill.skill_id=people_job_inventory.skill_id";
@@ -312,7 +302,6 @@ function people_edit_job_inventory($job_id,$group_id)
 
 function people_show_job_list($result, $edit=0)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_show_job_list($result, $edit=0) ';
   global $sys_datefmt;
   #takes a result set from a query and shows the jobs
 
@@ -368,7 +357,6 @@ function people_show_job_list($result, $edit=0)
 
 function people_show_project_jobs($group_id,$edit=0)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_show_project_jobs($group_id,$edit=0) ';
   #show open jobs for this project
   $sql="SELECT people_job.group_id,people_job.job_id,groups.group_name,groups.unix_group_name,groups.type,people_job.title,people_job.date,people_job_category.name AS category_name ".
      "FROM people_job,people_job_category,groups ".
@@ -383,7 +371,6 @@ function people_show_project_jobs($group_id,$edit=0)
 
 function people_project_jobs_rows($group_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_project_jobs_rows($group_id) ';
   #show open jobs for this project
   $sql="SELECT people_job.group_id,people_job.job_id,groups.group_name,people_job.title,people_job.date,people_job_category.name AS category_name ".
      "FROM people_job,people_job_category,groups ".
@@ -400,7 +387,6 @@ function people_project_jobs_rows($group_id)
 
 function people_skill_box($name='skill_id',$checked='xyxy')
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_skill_box ';
   global $PEOPLE_SKILL;
   if (!$PEOPLE_SKILL)
     {
@@ -413,7 +399,6 @@ function people_skill_box($name='skill_id',$checked='xyxy')
 
 function people_skill_level_box($name='skill_level_id',$checked='xyxy')
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_skill_level_box ';
   global $PEOPLE_SKILL_LEVEL;
   if (!$PEOPLE_SKILL_LEVEL)
     {
@@ -426,7 +411,6 @@ function people_skill_level_box($name='skill_level_id',$checked='xyxy')
 
 function people_skill_year_box($name='skill_year_id',$checked='xyxy')
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_skill_year_box ';
   global $PEOPLE_SKILL_YEAR;
   if (!$PEOPLE_SKILL_YEAR)
     {
@@ -439,7 +423,6 @@ function people_skill_year_box($name='skill_year_id',$checked='xyxy')
 
 function people_add_to_skill_inventory($skill_id,$skill_level_id,$skill_year_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_add_to_skill_inventory($skill_id,$skill_level_id,$skill_year_id) ';
   global $feedback;
   if (user_isloggedin())
     {
@@ -475,7 +458,6 @@ function people_add_to_skill_inventory($skill_id,$skill_level_id,$skill_year_id)
 
 function people_show_skill_inventory($user_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_show_skill_inventory($user_id) ';
   $sql="SELECT people_skill.name AS skill_name, people_skill_level.name AS level_name, people_skill_year.name AS year_name ".
      "FROM people_skill_year,people_skill_level,people_skill,people_skill_inventory ".
      "WHERE people_skill_year.skill_year_id=people_skill_inventory.skill_year_id ".
@@ -517,7 +499,6 @@ function people_show_skill_inventory($user_id)
 
 function people_edit_skill_inventory($user_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':people_edit_skill_inventory($user_id) ';
   global $PHP_SELF;
   $sql="SELECT *,people_skill.name AS skill_name FROM people_skill_inventory,people_skill WHERE user_id='$user_id' and people_skill.skill_id=people_skill_inventory.skill_id";
   $result=db_query($sql);
