@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: pre.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: pre.php 5268 2005-12-26 11:48:10Z toddy $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -159,7 +159,7 @@ require $GLOBALS['sys_www_topdir'].'/include/session.php';
 # theme - color scheme informations
 require $GLOBALS['sys_www_topdir'].'/include/theme.php';
 
-# title, helper to find out appropriate info depending on the context, 
+# title, helper to find out appropriate info depending on the context,
 # like title
 require $GLOBALS['sys_www_topdir'].'/include/context.php';
 
@@ -263,16 +263,16 @@ if (!isset($group_id) && !isset($group_name) && isset($item_id))
       exit_error(_("Item not found"));
     }
 
-  # Special case: if it the item is from the system group and we are on the 
+  # Special case: if it the item is from the system group and we are on the
   # cookbook, we may want to pretend that an item belong a given group while
   # it actually belongs to the system group.
   if (ARTIFACT == 'cookbook' &&
-      $group_id == $sys_group_id && 
+      $group_id == $sys_group_id &&
       sane_get("comingfrom"))
     {
       $group_id = sane_get("comingfrom");
     }
-  
+
 }
 
 # if we got a forum_id and no group_id, we need to get the appropriate
@@ -324,7 +324,7 @@ if (isset($group_id))
     {
       exit_error(_("Project not found"));
     }
-  
+
   # Ignore status of the project if being registered
   if (db_result($res_grp,0,'status') != 'I')
     {
@@ -354,7 +354,7 @@ if (isset($group_id))
   if (isset($group_id) && !$no_redirection)
     {
       $project = project_get_object($group_id);
-      if ($HTTP_HOST != $project->getTypeBaseHost() && $project->getTypeBaseHost())
+      if (strcasecmp($HTTP_HOST, $project->getTypeBaseHost()) != 0 && $project->getTypeBaseHost())
 	{
 	  header ('Location: http'.(session_issecure()?'s':'').'://'.$project->getTypeBaseHost().$_SERVER["REQUEST_URI"]);
 	  exit;
