@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: project_home.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: project_home.php 5287 2006-02-03 12:37:26Z ype $
 #
 # Copyright 1999-2000 (c) The SourceForge Crew
 # Copyright 2000-2003 (c) Free Software Foundation
@@ -31,7 +31,7 @@ require $GLOBALS['sys_www_topdir']."/include/vars.php";
 
 
 # if we are at wrong url, redirect
-if ($HTTP_HOST != $project->getTypeBaseHost() && $project->getTypeBaseHost())
+if (strcasecmp($HTTP_HOST, $project->getTypeBaseHost()) != 0 && $project->getTypeBaseHost())
 {
   header ("Location: http".(session_issecure()?'s':'')."://".$project->getTypeBaseHost().$PHP_SELF);
   exit;
@@ -138,10 +138,14 @@ if ($project->CanUse("license"))
 {
   $license = $project->getLicense();
   print _("License").' : ';
-  if ($LICENSE_URL[$license] != "0")
-    { print utils_link($LICENSE_URL[$license], $LICENSE[$license]); }
-  else
-    { print $LICENSE[$license]; }
+  if ($LICENSE_URL[$license] != "0") {
+    print utils_link($LICENSE_URL[$license], $LICENSE[$license]);
+  } else {
+    print $LICENSE[$license];
+    if ($license == "other") {
+      print '<br>'.$project->getLicense_other().'<br>';
+    }
+  }
 }
 print '<br />'._("Registration Date").' : '.format_date($sys_datefmt,$project->getStartDate())."\n";
 if ($project->CanUse("devel_status"))
