@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sendmail.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: sendmail.php 5285 2006-02-03 12:33:12Z ype $
 #
 #  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
 # 
@@ -142,7 +142,13 @@ function sendmail_mail ($from,
   $user_name  = array();
 
   while (list($k,$v) = each($to)) 
+
     {
+      if (is_numeric($v)) {
+        $touid = $v;
+      } else {
+        $touid = user_getid($v);
+      }
       # Exists in the exclude array? Skip it
       if ($exclude[$v])
         { continue; }
@@ -155,22 +161,22 @@ function sendmail_mail ($from,
       # local alias.
       if (!ereg("@", $v)) 
 	{
-	  if (user_exists($v)) 
+	  if (user_exists($touid)) 
             { 
                 # Exists in the exclude array? Skip it
-  	       if (is_array($exclude) && array_key_exists(user_getname($v), $exclude))
+  	       if (is_array($exclude) && array_key_exists(user_getname($touid), $exclude))
                   { continue; }
-
                 # Does the user have a specific subject line?
-                if (user_get_preference("subject_line", $v) != "")
+                if (user_get_preference("subject_line", $touid) != "")
                   {
                      $list[$i] = $v;
-                     $user_subject[$v] = sendmail_format_subject_line(user_get_preference("subject_line", $v), $savannah_project, $savannah_artifact, $savannah_artifact_id)." ".$subject;
-                     $user_name[$v] = user_getrealname($v, 1)." <".user_getemail($v).">";
+                     $user_subject[$v] = sendmail_format_subject_line(user_get_preference("subject_line", $touid), $savannah_project, $savannah_artifact, $savannah_artifact_id)." ".$subject;
+                     $user_name[$v] = user_getrealname($touid, 1)." <".user_getemail($touid).">";
                      $skip = 1;
                   }
 
-                $v = user_getrealname($v, 1)." <".user_getemail($v).">"; 
+                $v = user_getrealname($touid, 1)." <".user_getemail($touid).">"; 
+
             }
         }
     # If $v is set, add it to the list, 
@@ -308,4 +314,4 @@ function sendmail_create_msgid ()
   return date("Ymd-His", time()).".sv".user_getid().".".mt_rand(0,100000)."@".$_SERVER["HTTP_HOST"];
 }
 
-?>
\ No newline at end of file
+?>
