@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: data.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: data.php 5280 2006-02-01 17:55:45Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -531,13 +531,13 @@ function trackers_data_is_special($field, $by_field_id=false)
 function trackers_data_is_empty_ok ($field, $by_field_id=false)
 {
   return trackers_data_mandatory_flag($field, $by_field_id);
-}		  
+}
 
 function trackers_data_mandatory_flag ($field, $by_field_id=false)
 {
   # 1 = not mandatory
   # 0 = relaxed mandatory (mandatory if it was to the submitter)
-  # 3 = mandatory whenever possible 
+  # 3 = mandatory whenever possible
   global $BF_USAGE_BY_ID,$BF_USAGE_BY_NAME;
   if ($by_field_id)
     {
@@ -1351,11 +1351,11 @@ function trackers_data_add_history ($field_name,
   # If field is not to be kept in bug change history then do nothing
   if (!$force && !trackers_data_get_keep_history($field_name))
     { return; }
-  
+
   if (!user_isloggedin())
     {
       $user=100;
-    }  
+    }
   else
     {
       $user=user_getid();
@@ -1366,7 +1366,7 @@ function trackers_data_add_history ($field_name,
   if ($type)
     {
       $fld_type = ',type'; $val_type = ",'$type'";
-    } 
+    }
   else
     {
 	# No comment type specified for a followup comment
@@ -1376,8 +1376,8 @@ function trackers_data_add_history ($field_name,
 	  $fld_type = ',type'; $val_type = ",'100'";
 	}
     }
-  
-  
+
+
   $sql="INSERT INTO ".$artifact."_history (bug_id,field_name,old_value,new_value,mod_by,date $fld_type) ".
      "VALUES ('$item_id','$field_name','$old_value','$new_value','$user','".time()."' $val_type)";
   return db_query($sql);
@@ -1420,7 +1420,7 @@ function trackers_data_handle_update ($group_id,
       # highligthing missing fields.
       # (It is important that trackers_check_empty_fields set the global var
       # previous_form_bad_fields)
-      return false;      
+      return false;
     }
 
   # Get this bug from the db
@@ -1448,7 +1448,7 @@ function trackers_data_handle_update ($group_id,
   $changes = array();
   reset($vfl);
   while (list($field,$value) = each($vfl))
-    { 
+    {
       # $field_transition_id needed to be reset for every field in the loop
       # and $field_transition_accepted filled only if $field_transition_id
       # is not empty (otherwise transition automatic updates risk to be
@@ -1464,7 +1464,7 @@ function trackers_data_handle_update ($group_id,
       # special by the database
       if ($field == 'comment')
 	{ continue; }
-      
+
       $old_value = db_result($result,0,$field);
 
       # Handle field transitions checks+cc notif,
@@ -1511,7 +1511,7 @@ function trackers_data_handle_update ($group_id,
 
 	    }
 	}
-      
+
       $is_text = (trackers_data_is_text_field($field) || trackers_data_is_text_area($field));
       if  ($is_text)
 	{
@@ -1522,29 +1522,29 @@ function trackers_data_handle_update ($group_id,
 	  # if it is a date we must convert the format to unix time
           $date_value = $value;
 	  list($value,$ok) = utils_date_to_unixtime($value);
-	  
+
           # Users can be on different timezone ; The form
           # save only the day, month, year.
           # We cannot compare the timestamp (affected by timezone changes)
           $date_old_value = date("Y-n-j", $old_value);
-	  
+
 	  $differ = ($date_old_value != $date_value);
 	}
       else
 	{
 	  $differ = ($old_value != $value);
 	}
-      
+
       if ($differ)
 	{
-	  
+
           if ((trim($extra_addresses) != "") && (trim($field_transition_cc) != ""))
             {
 	      $extra_addresses .= ", ";
             }
 	  $extra_addresses .= $field_transition_cc;
-	  
-	  
+
+
 	  if ($is_text)
 	    {
 	      $upd_list .= "$field='".htmlspecialchars($value)."',";
@@ -1559,7 +1559,7 @@ function trackers_data_handle_update ($group_id,
 	      $upd_list .= "$field='$value',";
 	      trackers_data_add_history($field,$old_value,$value,$item_id);
 	    }
-	  
+
           # Keep track of the change
 	  $changes[$field]['del']=
 	    trackers_field_display($field,$group_id,$old_value,false,false,true,true);
@@ -1567,7 +1567,7 @@ function trackers_data_handle_update ($group_id,
 	     trackers_field_display($field,$group_id,$value,false,false,true,true);
 
           # Register transition id, if not empty
-          if ($field_transition_id != '') 
+          if ($field_transition_id != '')
             {
 	      $field_transition_accepted[] = $field_transition_id;
             }
@@ -1603,10 +1603,10 @@ function trackers_data_handle_update ($group_id,
       # Browse the canned responses
       while (list(,$thiscanned) = each($canned_response))
         {
-	  
+
 	  $sql="SELECT * FROM ".ARTIFACT."_canned_responses WHERE bug_canned_id='".addslashes($thiscanned)."'";
 	  $res3=db_query($sql);
-	  
+
 	  if ($res3 && db_numrows($res3) > 0)
 	    {
               # add a data separator
@@ -1647,7 +1647,7 @@ function trackers_data_handle_update ($group_id,
 	{
         $change_exists = 1;
         $upd_list .= "details='".safeinput($details)."',";
-	
+
 	# We should use "details" but since details are used for comment
 	# (which is really nasty), we simply cant.
 
@@ -1659,7 +1659,7 @@ function trackers_data_handle_update ($group_id,
 	if ($change >= 0)
 	  { $change = "+".$change; }
 	$change .= " chars";
-	
+
 	trackers_data_add_history('realdetails',
 				  htmlspecialchars($del_cut),
 				  htmlspecialchars($change),
@@ -1669,10 +1669,10 @@ function trackers_data_handle_update ($group_id,
 				  true);
 	$changes['realdetails']['add'] = stripslashes($change);
 	$changes['realdetails']['del'] = stripslashes($del_cut);
-	
+
 	}
     }
-  
+
 
   # Enter the timestamp if we are changing to closed or declined
   if (trackers_data_is_status_closed($vfl['status_id']))
@@ -1716,7 +1716,7 @@ function trackers_data_handle_update ($group_id,
 
   # If we are on the cookbook, Store related links
  if (ARTIFACT == 'cookbook')
-   { 
+   {
      cookbook_handle_update($item_id, $group_id);
    }
 
@@ -1733,9 +1733,9 @@ function trackers_data_handle_update ($group_id,
     }
   else
     {
-      if (!$change_exists) 
+      if (!$change_exists)
 	{
-	  fb(_("No field to update")); 
+	  fb(_("No field to update"));
           # must return false, otherwise a notif would be sent
 	  return false;
 	}
@@ -1930,31 +1930,16 @@ function trackers_data_reassign_item ($item_id,
 	  fb(_("Unable to add a comment with the original item report information."), 0);
 	}
 
-      # Duplicate attachment
-      $sql = "SELECT * FROM trackers_file WHERE item_id='".$item_id."' AND artifact='".ARTIFACT."'";
-      $res_attachment = db_query($sql);
-      while ($row_attachment = db_fetch_array($res_attachment))
+      # Usually, reassigning means duplicating data.
+      # In case of attached files, we simply reassign the file to another
+      # item. This could avoid wasting too much disk space as file are expected
+      # to be much bigger than CC list and alike.
+      $sql = "UPDATE trackers_file SET item_id='".$new_item_id."', artifact='".$reassign_change_artifact."' WHERE item_id='".$item_id."' AND artifact='".ARTIFACT."'";
+      $result = db_query($sql);
+      if (!$result)
 	{
-	  $sql = "INSERT INTO trackers_file ".
-	     "(item_id,artifact,submitted_by,date,description,file,filename,filesize,filetype) ".
-	     "VALUES ".
-	     "('".$new_item_id."','".
-             "'".$reassign_change_artifact."','".
-	     addslashes($row_attachment['submitted_by'])."','".
-	     addslashes($row_attachment['date'])."','".
-	     addslashes($row_attachment['description'])."','".
-	     addslashes($row_attachment['file'])."','".
-	     addslashes($row_attachment['filename'])."','".
-	     addslashes($row_attachment['filesize'])."','".
-	     addslashes($row_attachment['filetype'])."')";
-
-	  $result = db_query($sql);
-
-	  if (!$result)
-	    {
-	      fb(sprintf(_("Unable to duplicate an attached file (%s) from the original item report information."), $row_attachment['filename']), 1);
-	      dbg("sql: $sql");
-	    }
+	  fb(sprintf(_("Unable to duplicate an attached file (%s) from the original item report information."), $row_attachment['filename']), 1);
+	  dbg("sql: $sql");
 	}
 
       # Duplicate CC List
@@ -2032,7 +2017,7 @@ function trackers_data_update_dependent_items ($depends_on, $item_id, $artifact)
 # and handle_update be used instead.
 function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
 {
-  
+
   #we dont force them to be logged in to submit a bug
   if (!user_isloggedin())
     { $user=100; }
@@ -2046,7 +2031,7 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
       # highligthing missing fields.
       # (It is important that trackers_check_empty_fields set the global var
       # previous_form_bad_fields)
-      return false; 
+      return false;
     }
 
   # Finally, create the bug itself
@@ -2064,7 +2049,7 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
 
   # Build the variable list of fields and values
   # Remark: we must add open/closed by ourselves, as it is missing from the
-  # form for obvious reasons while automatic transitions may rely on its 
+  # form for obvious reasons while automatic transitions may rely on its
   # presence
   $vfl['status_id'] = '1';
   reset($vfl);
@@ -2152,8 +2137,16 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
 
   # Add all special fields that were not handled in the previous block
   $fixed_cols = 'close_date,group_id,submitted_by,date,summary,details';
+  # FIXME: Make an exception for the cookbook, since it currently requires
+  # HTML to be inserted. This is an ugly hack and should be fixed real soon.
+  $sql_details = htmlspecialchars($vfl['details']);
+  if (ARTIFACT == "cookbook")
+    {
+      # FIXME: This makes an XSS attack possible!
+      $sql_details = $vfl['details'];
+    }
   $fixed_values = "'0','$group_id','$user','".time()."','".
-     htmlspecialchars($vfl['summary'])."','".$vfl['details']."'";
+     htmlspecialchars($vfl['summary'])."','".$sql_details."'";
 
 
   $sql="INSERT INTO ".ARTIFACT." ($fixed_cols $vfl_cols) VALUES ($fixed_values $vfl_values)";
@@ -2171,7 +2164,7 @@ function trackers_data_create_item($group_id,$vfl,&$extra_addresses)
 
   # If we are on the cookbook, Store related links
   if (ARTIFACT == 'cookbook')
-   { 
+   {
      cookbook_handle_update($item_id,$group_id);
    }
 
@@ -2252,11 +2245,11 @@ function trackers_data_get_reports($group_id, $user_id=100, $sober=false)
 {
   # Currently, reports are group based.
   # Print first system reports.
-  
+
   # OUTDATED: currently personal query forms are deactivated in the code
   # If user is unknown then get only project-wide and system wide reports
   # else get personal reports in addition  project-wide and system wide.
-  
+
   # We usually want non-sober specific query forms.
   $system_scope = 'S';
   if ($sober)
