@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: general.php 5286 2006-02-03 12:35:22Z ype $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -1009,8 +1009,25 @@ function trackers_check_notification($user_id, $role, $changes=false)
   unset($changes['severity']);
   unset($changes['status_id']);
   unset($changes['CC']);
-  unset($changes['assigned_to']);
-  unset($changes['submitted_by']);
+
+# assignee and submitter related changes can't be unset globally. 
+# What needs to be unset is only what has been handled in this particular
+# call of the function
+
+  if (($changes['assigned_to']['add'] == $user_name) && ($role == 'ASSIGNEE')) {    unset($changes['assigned_to']['add']);
+  }
+  if (($changes['assigned_to']['del'] == $user_name) && ($role == 'ASSIGNEE')) {    unset($changes['assigned_to']['del']);
+  }
+  if (count($changes['assigned_to']) == 0) { unset($changes['assigned_to']);}
+                                                                                
+  if (($changes['submitted_by']['add'] == $user_name) && ($role == 'SUBMITTER')) {
+    unset($changes['submitted_by']['add']);
+  }
+  if (($changes['submitted_by']['del'] == $user_name) && ($role == 'SUBMITTER')) {
+    unset($changes['submitted_by']['del']);
+  }
+  if (count($changes['submitted_by']) == 0) { unset($changes['submitted_by']);}
+
   if ($arr_notif[$role]['ANY_OTHER_CHANGE'] && count($changes))
     {
       #echo "DBG ANY_OTHER_CHANGE notified<br />";
@@ -1371,7 +1388,7 @@ function trackers_exist_cc($item_id,$cc)
 function trackers_insert_cc($item_id,$cc,$added_by,$comment,$date)
 {
   $sql = "INSERT INTO ".ARTIFACT."_cc (bug_id,email,added_by,comment,date) ".
-     "VALUES ('$item_id','$cc','$added_by','$comment','$date')";
+     "VALUES ('$item_id','$cc','$added_by','".htmlspecialchars($comment)."','$date')";
   $res = db_query($sql);
 
   trackers_data_add_history("Carbon-Copy",
