@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: browse.php,v 1.66 2005/09/26 12:53:45 yeupou Exp $
+# $Id: browse.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -24,6 +24,17 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+# There are parameters that defined before, in the pages that include browse.
+# For instance, $sober is defined by the cookbook/index.php page
+
+
+$preference_prefix = ARTIFACT;
+if ($sober)
+{
+  $preference_prefix .= "-sober";
+}
+
+
 # Number of search criteria (boxes) displayed in one row
 $fields_per_line=5;
 
@@ -32,10 +43,12 @@ unset($browse_preamble);
 
 # Number of bugs displayed on screen in one chunk.
 # Default 50
+$chunksz = sane_get("chunksz");
 if (!$chunksz)
 { $chunksz = 50; }
 
 # Digest mode? Set the digest variable to one
+$func = sane_get("func");
 if ($func == "digest")
 { $digest = 1; }
 else
@@ -46,6 +59,7 @@ else
 
 
 # Make sure offset is defined and has a correct value
+$offset = sane_get("offset");
 if (!$offset || $offset < 0)
 { $offset=0; }
 
@@ -76,6 +90,7 @@ unset($url_params['history_date']);
 #   will avoid to deal with scalar in simple search and array in
 #   advanced which would greatly complexifies the code)
 # ================================================== */
+$advsrch = sane_get("advsrch");
 while (list($field,$value_id) = each($url_params))
 {
   if (!is_array($value_id))
@@ -109,6 +124,10 @@ while (list($field,$value_id) = each($url_params))
 }
 
 # If history event additional constraint is used, add it
+$history_search = sane_get("history_search");
+$history_date_yearfd = sane_get("history_date_yearfd");
+$history_date_monthfd = sane_get("history_date_monthfd");
+$history_date_dayfd = sane_get("history_date_dayfd");
 if ($history_search)
 {
   # Dates must numeric date, even can be only modified or unmodified
@@ -132,10 +151,13 @@ if ($history_search)
 #  ================================================== 
 
 #print "<br />DBG \$morder at top: [$morder ]";
-#   if morder not defined then reuse the one in preferences
+$morder = sane_get("morder");
+$order = sane_get("order");
+
+# if morder not defined then reuse the one in preferences
 if (user_isloggedin() && !isset($morder))
 {
-  $morder = user_get_preference(ARTIFACT.'_browse_order'.$group_id);
+  $morder = user_get_preference($preference_prefix.'_browse_order'.$group_id);
 }
 
 if (isset($order))
@@ -147,26 +169,30 @@ if (isset($order))
     }
   else
     {
-      # reset list of sort criteria
+      # Reset list of sort criteria 
       $morder = '';
     }
 }
 
-if (isset($morder))
+if ($morder != '')
 {
-
+  # If the user is logged in, save the wanted order if different from the
+  # current
   if (user_isloggedin())
     {
-      if ($morder != user_get_preference(ARTIFACT.'browse_order'.$group_id))
-	user_set_preference(ARTIFACT.'_browse_order'.$group_id, $morder);
-    }
-
-  if ($morder != '')
-    {
-      $order_by = ' ORDER BY '.trackers_criteria_list_to_query($morder);
+      if ($morder != user_get_preference($preference_prefix.'_browse_order'.$group_id))
+	{
+	  user_set_preference($preference_prefix.'_browse_order'.$group_id, $morder);
+	}
     }
 }
 
+# Fill the relevant sql bit to be used later
+# Sensible default case: order by item_id from the recent to the older
+if ($morder == '')
+{ $morder = "bug_id<"; }
+$order_by = ' ORDER BY '.trackers_criteria_list_to_query($morder);
+
 #print "<BR>>DBG Order by = $order_by";
 
 
@@ -175,22 +201,31 @@ if (isset($morder))
 #  If it is set then update the user preference.  Also initialize the
 #  bug report structures.
 #  ================================================== 
+$report_id = sane_get("report_id");
 if (user_isloggedin())
 {
   if (!isset($report_id))
     {
-      $report_id = user_get_preference(ARTIFACT.'_browse_report'.$group_id);
+      $report_id = user_get_preference($preference_prefix.'_browse_report'.$group_id);
     }
   else
     {
-      if ($report_id != user_get_preference(ARTIFACT.'_browse_report'.$group_id))
-	user_set_preference(ARTIFACT.'_browse_report'.$group_id, $report_id);
+      if ($report_id != user_get_preference($preference_prefix.'_browse_report'.$group_id))
+	user_set_preference($preference_prefix.'_browse_report'.$group_id, $report_id);
     }
 }
 
-# If still not defined then force it to system 'Default' report
+# If still not defined then force it to system 'Basic' report
+# of to 'Sober Basic' in sober mode, 103. This is hardcoded, if at some point
+# we need to put the sober output of existing trackers where 103 may already
+# be used, we will have to think of an other way to put it.
 if (!$report_id)
-{ $report_id=100; }
+{
+  if (!$sober)
+    { $report_id = 100; }
+  else
+    { $report_id = 103; }
+} 
 
 trackers_report_init($group_id, $report_id);
 
@@ -204,13 +239,14 @@ trackers_report_init($group_id, $report_id);
 #     (Prefs is a string of the form
 #     &amp;field1[]=value_id1&amp;field2[]=value_id2&amp;.... )
 #  ================================================== 
+$set = sane_get("set");
 if (!$set)
 {
 
   if (user_isloggedin())
     {
 
-      $custom_pref=user_get_preference(ARTIFACT.'_brow_cust'.$group_id);
+      $custom_pref=user_get_preference($preference_prefix.'_brow_cust'.$group_id);
 
       if ($custom_pref)
 	{
@@ -306,10 +342,10 @@ else if ($set=='custom')
   $pref_stg .= '&amp;report_id='.$report_id;
   $pref_stg .= '&amp;sumORdet='.$sumORdet;
 
-  if ($pref_stg != user_get_preference('bug_brow_cust'.$group_id))
+  if ($pref_stg != user_get_preference($preference_prefix.'_brow_cust'.$group_id))
     {
       #print "<br /> DBG setting pref = $pref_stg";
-      user_set_preference(ARTIFACT.'_brow_cust'.$group_id,$pref_stg);
+      user_set_preference($preference_prefix.'_brow_cust'.$group_id,$pref_stg);
     }
 
 }
@@ -328,13 +364,35 @@ if (!isset($advsrch))
 { $advsrch = 0; }
 if (!isset($msort))
 { $msort = 0; }
+
+# Will be used later to find out if it make sense to look for items of the
+# system group (meaningful on the cookbook)
+$not_group_specific = 1;
+
 while ($field = trackers_list_all_fields())
 {
   # the select boxes for the bug DB search first
   if (trackers_data_is_showed_on_query($field) &&
       trackers_data_is_select_box($field) )
     {
-      if (!isset($url_params[$field])) $url_params[$field][] = 0;
+      if (!isset($url_params[$field])) 
+	{ $url_params[$field][] = 0; }
+
+      # If we are about to generate the sober output, find out if we can
+      # look for items of the site admin project or not. 
+      # All fields that have preconfigured values that can be changed by
+      # projects could end up in flawed results, because the value id and the
+      # actual value label (and so, meaning) are likely to be out of sync.
+      # The most obvious case if the category field case.
+      if (ARTIFACT == 'cookbook' && $sober)
+	{
+	  if (trackers_data_is_project_scope($field) && 
+	      $url_params[$field][0] != '0' &&
+	      $url_params[$field][0] != '100')
+	    {
+	      $not_group_specific = 0;
+	    }
+	}         
     }
 }
 
@@ -347,10 +405,24 @@ while ($field = trackers_list_all_fields())
 # item title is provided to everybody.
 $full_field_list = $col_list = $lbl_list = array();
 $select_count = 'SELECT count(DISTINCT '.ARTIFACT.'.bug_id) AS count ';
-$select = 'SELECT DISTINCT '.ARTIFACT.'.priority,'.ARTIFACT.'.privacy,'.ARTIFACT.'.status_id';
+$select = 'SELECT DISTINCT '.ARTIFACT.'.group_id,'.ARTIFACT.'.priority,'.ARTIFACT.'.privacy,'.ARTIFACT.'.status_id';
 $from = 'FROM '.ARTIFACT.' ';
-$where = 'WHERE '.ARTIFACT.'.group_id='.$group_id.' ';
-$limit = " LIMIT $offset,$chunksz";
+
+# On the cookbook in sober mode, we want the system wide recipes,
+# as long as there is no field that comes as select boxes with values 
+# configurable per project set.
+if (ARTIFACT == 'cookbook' && $sober && $not_group_specific)
+{
+  $where = 'WHERE ('.ARTIFACT.'.group_id='.$group_id.' OR '.ARTIFACT.'.group_id='.$sys_group_id.') ';
+}
+else
+{
+  $where = 'WHERE '.ARTIFACT.'.group_id='.$group_id.' ';
+}
+# No limit on sober output, we want all recipes
+unset($limit);
+if (!$sober)
+{ $limit = " LIMIT $offset,$chunksz"; }
 
 
 # prepare the where clause with the selection criteria given by the user
@@ -489,9 +561,12 @@ $details_search = 0;
 
 while ($field = trackers_list_all_fields(cmp_place_query))
 {
+  # Skip unused field
+  if (!trackers_data_is_used($field))
+    { continue; }
 
-  if (!trackers_data_is_used($field) ||
-      !trackers_data_is_showed_on_query($field))
+  # Skip fields not part of this query form
+  if (!trackers_data_is_showed_on_query($field))
     { continue; }
 
   # beginning of a new row
@@ -742,10 +817,12 @@ while ($thisarray = db_fetch_array($result))
       continue; 
     }
 
-  # Check if we must ignore it due to privacy rights
-
   # Build a specific array for each item
   $result_array[$thisitem_id] = array();
+  
+  # Always store the group, it may be necessary later, in case we actually
+  # look for items from different projects  
+  $result_array[$thisitem_id]["group_id"] = $thisarray["group_id"];   
 
   # Store each field that will be necessary later
   $nb_of_fields = count($full_field_list);
@@ -759,7 +836,7 @@ while ($thisarray = db_fetch_array($result))
 #while (list(,$thisitem) = each($result_array))
 #{
 #  $thisitem_id = $thisitem['bug_id'];
-#  print "TEST ".$thisitem_id.", ".$result_array[$thisitem_id]["summary"]." --";
+#  print "TEST ".$thisitem_id.", ".$result_array[$thisitem_id]["summary"].", ".$result_array[$thisitem_id]["resolution_id"].", ".$result_array[$thisitem_id]["group_id"]." -- ";
 #}
 
 
@@ -789,10 +866,20 @@ $form = '
           '._("Browse").' ';
 
 # Show the list of available bug reports kind
-$res_report = trackers_data_get_reports($group_id,user_getid());
+$res_report = trackers_data_get_reports($group_id,user_getid(),$sober);
 if (!$printer)
 {
-  $form .= sprintf(_("with the %s query form"), html_build_select_box($res_report,'report_id',$report_id,true,'Basic'));
+  # In sober mode, there is no relevant query form that have reportid = 100
+  $show_100 = true;
+  if ($sober)
+    { $show_100 = false; }
+
+  $form .= sprintf(_("with the %s query form"), 
+		   html_build_select_box($res_report,
+					 'report_id',
+					 $report_id,
+					 $show_100,
+					 'Basic'));  # basic == 100
 }
 else
 { 
@@ -871,15 +958,19 @@ if (($details_search == 1) && ($summary_search == 1))
   if (!$printer)
     {
       $form .= '<p class="smaller">'.
-	sprintf(_("Use logical %s between Summary and Original Submission searches."),
-		'<select name="sumORdet"><option value="0" '.(!$sumORdet ? 'selected="selected"':'').'>'._("AND").'</option><option value="1" '.($sumORdet ? 'selected="selected"':'').'>'._("OR").'</option></select>').
+	sprintf(_("Use logical %s between '%s' and '%s' searches."),
+		'<select name="sumORdet"><option value="0" '.(!$sumORdet ? 'selected="selected"':'').'>'._("AND").'</option><option value="1" '.($sumORdet ? 'selected="selected"':'').'>'._("OR").'</option></select>',
+		rtrim(trackers_field_label_display("summary", $group_id, false,true), ': '),
+		rtrim(trackers_field_label_display("details", $group_id, false,true), ': ')).
 	'</p>';
     }
   else
     {
       $form .= '<p class="smaller">'.
-	sprintf(_("Use logical %s between Summary and Original Submission searches."),
-		($sumORdet ? _("OR"):_("AND"))).
+	sprintf(_("Use logical %s between '%s' and '%s' searches."),
+		($sumORdet ? _("OR"):_("AND")),
+		rtrim(trackers_field_label_display("summary", $group_id, false,true), ': '),
+		rtrim(trackers_field_label_display("details", $group_id, false,true), ': ')).
 	'</p>';
     }
   
@@ -888,29 +979,35 @@ if (($details_search == 1) && ($summary_search == 1))
 }
 
 
-# Propose to search for field updated since a certain date
-$i=0;
+## Propose to search for field updated since a certain date
+$fextracted = array();
 $fname = array();
 $flabel = array();
+
+# Extract the list of relevant fields
 while ($field = trackers_list_all_fields()) 
 {
   # Do not show fields not used by the project
   if ( !trackers_data_is_used($field)) 
     { continue; }
-     # Do not show some special fields any way
+
+  # Special fields are usually not modifiable by users, it is the system
+  # that defines their content. As such, they cannot be used as 
+  # additional constraint.
   if (trackers_data_is_special($field)) 
-    {
-      if (($field == 'group_id') || ($field == 'comment_type_id'))
-	{ continue; }
-    }
-  if ($field == 'bug_id') 
     { continue; }
   
-  $fname[] = $field;
-  $flabel[] = trackers_data_get_label($field);
-  $i++;
+  $fextracted[$field] = trackers_data_get_label($field);
 }
 
+# Order them by name: in a select box, following the configure output order
+# is not user-friendly.
+asort($fextracted);
+while (list($field,$label) = each($fextracted)) 
+{
+  $fname[] = $field;
+  $flabel[] = $label;
+}
 
 $hist_ev_text  = array();
 $hist_ev_text[] = _("modified");
@@ -919,55 +1016,62 @@ $hist_ev_value  = array();
 $hist_ev_value[] = "modified";
 $hist_ev_value[] = "not modified";
 
-if (!$printer)
+# If we are in sober mode, additional constraint is not proposed
+if (!$sober)
 {
-  $form .= '<p class="smaller"><span class="preinput">'.sprintf(_("Additional constraint %s:"),	'<select name="history_search"><option value="0" '.(!$history_search ? 'selected="selected"':'').'>'._("deactivated").'</option><option value="1" '.($history_search ? 'selected="selected"':'').'>'._("activated").'</option></select>').'</span><br />&nbsp;&nbsp;&nbsp;'.
-    # I18N
-    # This is for specifying additional constraints for the result list.
-    # The first string is the fieldname (e.g. "category", "privacy", "status"),
-    # the second is currently either "modified" or "not modified", and the
-    # third string is a date.
-    # Full example: "Severity not modified since 14. September 2005"
-    sprintf(_("%s%s since %s"),
-	    html_build_select_box_from_arrays ($fname,
-					       $flabel,
-					       'history_field',
-					       $history_field, 
-					       false,
-					       '',
-					       true,
-					       'Any', 
-					       false),
-	    html_build_select_box_from_arrays ($hist_ev_value,
-					       $hist_ev_text,
-					       'history_event',
-					       $history_event,
-					       false,
-					       '',
-					       false,
-					       '',
-					       false),
-	    trackers_field_date('history_date',
-				$history_date,
-				0,
-				0,
-				false)).'</p>';
-}
-else
-{
-  # In printer mode, if the additional constrait is off, no need to print it
-  if ($history_search)
+  if (!$printer)
     {
-      $form .= '<p class="smaller"><span class="preinput">'.sprintf(_("Additional constraint %s:"), _("activated")).
-	'</span> '.
+      $form .= '<p class="smaller"><span class="preinput">'.sprintf(_("Additional constraint %s:"),	'<select name="history_search"><option value="0" '.(!$history_search ? 'selected="selected"':'').'>'._("deactivated").'</option><option value="1" '.($history_search ? 'selected="selected"':'').'>'._("activated").'</option></select>').'</span><br />&nbsp;&nbsp;&nbsp;'.
+	
+     # I18N
+     # This is for specifying additional constraints for the result list.
+     # The first string is the fieldname 
+     # (e.g. "category", "privacy", "status"),
+     # the second is currently either "modified" or "not modified", and the
+     # third string is a date.
+     # Full example: "Severity not modified since 14. September 2005"
 	sprintf(_("%s%s since %s"),
-		$flabel[$history_field],
-		$hist_ev_text[$history_event],
+		html_build_select_box_from_arrays ($fname,
+						   $flabel,
+						   'history_field',
+						   $history_field, 
+						   false,
+						   '',
+						   true,
+						   'Any', 
+						   false),
+		html_build_select_box_from_arrays ($hist_ev_value,
+						   $hist_ev_text,
+						   'history_event',
+						   $history_event,
+						   false,
+						   '',
+						   false,
+						   '',
+						   false),
 		trackers_field_date('history_date',
 				    $history_date,
 				    0,
 				    0,
-				    true)).'</p>';
+				    false)).'</p>';
+    }
+  else
+    {
+      # In printer mode, if the additional constrait is off,
+      # no need to print it
+      if ($history_search)
+	{
+	  $form .= '<p class="smaller"><span class="preinput">'.sprintf(_("Additional constraint %s:"), _("activated")).
+	    '</span> '.
+	    sprintf(_("%s%s since %s"),
+		    $flabel[$history_field],
+		    $hist_ev_text[$history_event],
+		    trackers_field_date('history_date',
+					$history_date,
+					0,
+					0,
+					true)).'</p>';
+	}
     }
 }
 if ($history_search)
@@ -978,17 +1082,23 @@ if ($history_search)
 
 
 # Number of items printed at once
-if (!$printer)
+# In sober mode, they are all printed
+if (!$sober)
 {
-  $form .= '<p class="smaller">'.sprintf(_("Show %s items at once."), '<input type="text" name="chunksz" size="3" maxlength="5" '.
-    'value="'.$chunksz.'" />').'</p>';
-}
-else
-{
-  $form .= '<p class="smaller">'.sprintf(_("Show %s items at once."), $chunksz).'</p>';
+  if (!$printer)
+    {
+      $form .= '<p class="smaller">'.sprintf(_("Show %s items at once."), '<input type="text" name="chunksz" size="3" maxlength="5" '.
+					     'value="'.$chunksz.'" />').'</p>';
+    }
+  else
+    {
+      $form .= '<p class="smaller">'.sprintf(_("Show %s items at once."), $chunksz).'</p>';
+    }
 }
 
-if ($totalrows > 0)
+# In sober mode, do not talk about sorting order, we will anyway not use
+# tables to sort the items
+if ($totalrows > 0 && !$sober)
 {
   $form .= '<p class="smaller">';
   if ($msort)
@@ -1032,15 +1142,23 @@ if ($digest)
 
 if ($totalrows > 0)
 {
-
-  show_item_list($result_array,$offset,$totalrows,$col_list,$lbl_list,$width_list,$url,false);
-  
-  if ($digest)
+  if (!$sober)
     {
-      print form_footer(_("Proceed to Digest next step"));
-    }
+      
+      show_item_list($result_array,$offset,$totalrows,$col_list,$lbl_list,$width_list,$url,false);
+      
+      if ($digest)
+	{
+	  print form_footer(_("Proceed to Digest next step"));
+	}
 
-  show_priority_colors_key();
+      show_priority_colors_key();
+    }
+  else
+    {
+      # Sober got it is own list design
+      show_item_list_sober($result_array,$totalrows,$width_list,$url,false);
+    }
 
 }
 else
