@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: index.php 5278 2006-02-01 17:37:31Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -372,7 +372,7 @@ if ($group_id && user_ismember($group_id,'A'))
     else
       {
 	print '<p>';
-	print _("You can administrate list information from here. Please note that private lists are only displayed for members of your project, but not for visitors who are not logged in.")."<br />\n";
+	print _("You can administer list information from here. Please note that private lists are only displayed for members of your project, but not for visitors who are not logged in.")."<br />\n";
 	print _("Note that if you change the status of the mailing list to \"Deleted\", it will have no other effect than the list is no longer displayed to the developers and visitors.");
 	print "</p>\n";
 
@@ -410,7 +410,7 @@ if ($group_id && user_ismember($group_id,'A'))
 					<TD>';
 	    if ($project->getTypeMailingListAdminUrl())
 	      {
-		print '<A href="'.$project->getTypeMailingListAdminUrl(db_result($result,$i,'list_name')).'">['._("Administrate this list").']</a>';
+		print '<A href="'.$project->getTypeMailingListAdminUrl(db_result($result,$i,'list_name')).'">['._("Administer this list").']</a>';
 
 		print '
 				       </TD></TR></FORM>';
@@ -567,7 +567,7 @@ if ($group_id && user_ismember($group_id,'A'))
     print '
 <A HREF="'.$PHP_SELF.'?group='.$group_name.'&add_list=1">'._("Add Mailing List").'</A><p class="text">'._("You can create mailing lists for your project using the web interface.").'</p>
 
-<A HREF="'.$PHP_SELF.'?group_id='.$group_id.'&change_status=1">'._("Administrate/Update Lists").'</A><p class="text">'._("Update information on existing mailing lists and change their policy.").'</p>
+<A HREF="'.$PHP_SELF.'?group_id='.$group_id.'&change_status=1">'._("Administer/Update Lists").'</A><p class="text">'._("Update information on existing mailing lists and change their policy.").'</p>
 			';
 
     if ($isgnu == true)
