@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: votes.php,v 1.2 2005/08/31 21:05:09 yeupou Exp $
+# $Id: votes.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 2005      (c) Mathieu Roy <yeupou--gnu.org>
 #
@@ -68,7 +68,8 @@ if (user_isloggedin())
       $remaining_votes = trackers_votes_user_remains_count(user_getid());
     }
 
-  site_user_header(array('toptab'=>'votes'));
+  site_user_header(array('context'=>'votes'));
+
 
   # Simple listing. No need of anything really fancy, there will be no more 
   # than hundred entries
