@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: submit.php,v 1.28 2005/06/30 17:19:36 toddy Exp $
+# $Id: submit.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -113,7 +113,8 @@ if (!$group_id)
 # Show the submit form
 site_project_header(array('title'=>_("Submit News"),
 			  'group'=>$group_id,
-			  'toptab'=>'news'));
+			  'context'=>'news'));
+
 
 if($feedback)
 {
