@@ -36,7 +36,8 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
 		Fill in the info to create a job
   */
 
-  site_project_header(array('title'=>_("Create a job for your project"),'group'=>$group_id,'toptab'=>'ahome'));
+  site_project_header(array('title'=>_("Create a job for your project"),'group'=>$group_id,'context'=>'ahome'));
+
 
   # we get site-specific content
   utils_get_content("people/createjob");
