@@ -143,7 +143,8 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
   */
   if ($job_id) {
 
-    site_project_header(array('title'=>_("Edit a job for your project"),'group'=>$group_id,'toptab'=>'ahome'));
+    site_project_header(array('title'=>_("Edit a job for your project"),'group'=>$group_id,'context'=>'ahome'));
+
     #for security, include group_id
     $sql="SELECT * FROM people_job WHERE job_id='$job_id' AND group_id='$group_id'";
     $result=db_query($sql);
@@ -186,7 +187,8 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
     }
   } else {
 
-    site_project_header(array('title'=>_("Looking for a job to Edit"),'group'=>$group_id,'toptab'=>'ahome'));
+    site_project_header(array('title'=>_("Looking for a job to Edit"),'group'=>$group_id,'context'=>'ahome'));
+
 
     print '<p>'
       ._("Here is a list of positions available for this project, choose the one you want to modify.").'</p>';
