@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: viewjob.php,v 1.29 2005/06/30 17:19:36 toddy Exp $
+# $Id: viewjob.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -32,7 +32,8 @@ if ($group_id && $job_id)
   /*
 		Fill in the info to create a job
   */
-  site_project_header(array('title'=>_("View a Job"),'group'=>$group_id,'toptab'=>'home'));
+  site_project_header(array('title'=>_("View a Job"),'group'=>$group_id,'context'=>'home'));
+
   #  people_header(array('title'=>'View a Job'));
 
 
