@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: editgroupinfo.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: editgroupinfo.php 5263 2005-12-12 10:03:02Z toddy $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -56,7 +56,7 @@ if (db_numrows($res_grp) < 1)
 $row_grp = db_fetch_array($res_grp);
 
 
-site_project_header(array('title'=>_("Editing Public Infos"),'group'=>$group_id,'context'=>'ahome'));
+site_project_header(array('title'=>_("Editing Public Info"),'group'=>$group_id,'context'=>'ahome'));
 
 
 
