@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: useradmin.php,v 1.16 2005/09/14 08:24:07 yeupou Exp $
+# $Id: useradmin.php 5187 2005-12-01 16:22:29Z yeupou $
 #
-#  Copyright 2003-2004 (c) Frederik Orellana <frederik.orellana--cern.ch>
+#  Copyright 2003-2005 (c) Frederik Orellana <frederik.orellana--cern.ch>
 #                          Derek Feichtinger <derek.feichtinger--cern.ch>
 #                          Mathieu Roy <yeupou--gnu.org>
 #
@@ -25,10 +25,13 @@
 require "../../include/pre.php";
 
 session_require(array('group'=>$group_id,'admin_flags'=>'A'));
+if (!$group_id) 
+{
+  exit_no_group();
+} 
 
 function show_pending_users_list ($result, $group_id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_pending_users_list ($result, $group_id) ';
   global $PHP_SELF;
   print "<h3>"._("Users Pending for Group")."</h3>
 	<p>
@@ -59,7 +62,7 @@ function show_pending_users_list ($result, $group_id)
 
 function show_all_users_remove_list ($result, $result2, $group_id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_all_users_remove_list ($result, $group_id) ';  global $PHP_SELF;
+ global $PHP_SELF;
   print "
         <h3>"._("Removing users from group")."</h3>
 	<p>
@@ -102,7 +105,7 @@ function show_all_users_remove_list ($result, $result2, $group_id)
 
 function show_all_users_add_searchbox ($group_id, $previous_search)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_all_users_add_searchbox ($group_id, $previous_search) ';  global $PHP_SELF;
+	global $PHP_SELF;
   print '
         <h3><a name="searchuser"></a>'._("Adding users to group").'</h3>
 	<p>
@@ -121,7 +124,7 @@ function show_all_users_add_searchbox ($group_id, $previous_search)
 
 function show_all_users_add_list ($result, $group_id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_all_users_add_list ($result, $group_id) ';  global $PHP_SELF;
+	global $PHP_SELF;
   print _("Below is the result of your search in the users database.")."
 
 	<P></P>
@@ -152,7 +155,6 @@ function show_all_users_add_list ($result, $group_id)
 
 function show_bulk_add_users ($group_id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_bulk_add_users ($group_id) ';
         print "<h3>"._("Have your file checked")."</h3>\n\n";
 
   print _("By submitting your file here, the format of the file and each user name, etc. will be checked. No modifications will be made to the user database. Feedback will be given on screen and by email.");
@@ -187,9 +189,7 @@ function show_bulk_add_users ($group_id)
 
 # Administrative functions
 
-/*
-	Add a user to this group
-*/
+# Add a user to this group
 if ($action=='add_to_group' && $user_id) {
   $sys_approved_user_permissions = $GLOBALS['sys_approved_user_permissions'];
   foreach ($user_id as $user) {
@@ -198,9 +198,7 @@ if ($action=='add_to_group' && $user_id) {
   }
 }
 
-/*
-	Remove a user from this group
-*/
+# Remove a user from this group
 if ($action=='remove_from_group' && $user_id) {
   foreach ($user_id as $user) {
     # Check if the users about to be removed are not admins
@@ -211,9 +209,7 @@ if ($action=='remove_from_group' && $user_id) {
   }
 }
 
-/*
-	Approve a user for this group
-*/
+# Approve a user for this group
 if ($action=='approve_for_group' && $user_id) {
   foreach ($user_id as $user) {
     member_approve($user, $group_id);
@@ -239,86 +235,59 @@ if ($action=='approve_for_group' && $user_id) {
   }
 }
 
-
+############
 # Start the page
-site_project_header(array('title'=>_("Manage Members"),'group'=>$group_id,'toptab'=>'ahome'));
+site_project_header(array('title'=>_("Manage Members"),'group'=>$group_id,'context'=>'ahome'));
 
 
-/*
-	Show lists of users
-*/
+# Show a form so a user can be approved for this group
 
+$result =  db_query("SELECT user.user_id AS user_id, "
+		    . "user.user_name AS user_name, "
+		    . "user.realname AS realname "
+		    . "FROM user,user_group "
+		    . "WHERE user.user_id=user_group.user_id AND user_group.group_id='$group_id' AND admin_flags='P'"
+		    . "ORDER BY user.user_name");
 
-if (!$group_id) {
+show_pending_users_list($result, $group_id);
 
-  exit_error('No group id given', $group_id);
+print '<br />';
 
-} else {
-  /*
-		Show list for one group
-  */
+# Show a form so a user can be removed from this group
+$result =  db_query("SELECT user.user_id AS user_id, "
+		    . "user.user_name AS user_name, "
+		    . "user.realname AS realname "
+		    . "FROM user,user_group "
+		    . "WHERE user.user_id=user_group.user_id AND user_group.group_id=$group_id AND admin_flags<>'A' AND admin_flags<>'P'"
+		    . "ORDER BY user.user_name");
 
-  $HTML->box1_top(sprintf(_("Member administration for %s"), group_getname($group_id)));
+$result2 =  db_query("SELECT user.user_id AS user_id, "
+		     . "user.user_name AS user_name, "
+		     . "user.realname AS realname "
+		     . "FROM user,user_group "
+		     . "WHERE user.user_id=user_group.user_id AND user_group.group_id=$group_id AND admin_flags='P'"
+		     . "ORDER BY user.user_name");
 
-  /*
-        	Show a form so a user can be approved for this group
-  */
+show_all_users_remove_list($result, $result2, $group_id);
 
-  $result =  db_query("SELECT user.user_id AS user_id, "
-		      . "user.user_name AS user_name, "
-		      . "user.realname AS realname "
-		      . "FROM user,user_group "
-		      . "WHERE user.user_id=user_group.user_id AND user_group.group_id='$group_id' AND admin_flags='P'"
-		      . "ORDER BY user.user_name");
+print '<br />';
 
+# Show a form so a user can be added to this group
 
-  show_pending_users_list($result, $group_id);
+# Query to find users
+$array = explode(" ",$words);
+$words1=implode($array,"%' OR user_name LIKE '%");
+$words2=implode($array,"%' OR realname LIKE '%");
+$result = db_query("SELECT user_id, user_name, realname "
+		   . "FROM user "
+		   . "WHERE ((user_name LIKE '%$words1%') OR (realname LIKE '%$words2%')) AND (status='A') ORDER BY user_name LIMIT 0,26");
 
-  print '<br /></td></tr><tr><td class="boxitemalt">';
+show_all_users_add_searchbox($group_id, $words);
 
-  /*
-        	Show a form so a user can be removed from this group
-  */
-  $result =  db_query("SELECT user.user_id AS user_id, "
-		      . "user.user_name AS user_name, "
-		      . "user.realname AS realname "
-		      . "FROM user,user_group "
-		      . "WHERE user.user_id=user_group.user_id AND user_group.group_id=$group_id AND admin_flags<>'A' AND admin_flags<>'P'"
-		      . "ORDER BY user.user_name");
+if ($words) {
+  show_all_users_add_list($result, $group_id);
+}
 
-  $result2 =  db_query("SELECT user.user_id AS user_id, "
-		      . "user.user_name AS user_name, "
-		      . "user.realname AS realname "
-		      . "FROM user,user_group "
-		      . "WHERE user.user_id=user_group.user_id AND user_group.group_id=$group_id AND admin_flags='P'"
-		      . "ORDER BY user.user_name");
-
-  show_all_users_remove_list($result, $result2, $group_id);
-
-
-  print '<br /></td></tr><tr><td class="boxitem">';
-
-  /*
-        	Show a form so a user can be added to this group
-  */
-
-  # Query to find users
-  $array = explode(" ",$words);
-  $words1=implode($array,"%' OR user_name LIKE '%");
-  $words2=implode($array,"%' OR realname LIKE '%");
-  $result = db_query("SELECT user_id, user_name, realname "
-		     . "FROM user "
-		     . "WHERE ((user_name LIKE '%$words1%') OR (realname LIKE '%$words2%')) AND (status='A') ORDER BY user_name LIMIT 0,26");
-
-  show_all_users_add_searchbox($group_id, $words);
-
-  if ($words) {
-    show_all_users_add_list($result, $group_id);
-  }
-
-  $HTML->box1_bottom();
-
-  print '<p></p>';
 
   /*
         	Show a form to upload a bulk-add script
@@ -331,7 +300,6 @@ if (!$group_id) {
 
   $HTML->box1_bottom();
   */
-}
 
 project_admin_footer(array());
 
